@@ -75,6 +75,21 @@ set( 'SQL_PRIVHISTORY_SELECT_CURRENT', q/
       FETCH FIRST ROW ONLY
       / );
 
+# SQL_PRIVHISTORY_SELECT_BY_PHID
+#     SQL to select a privhistory record by its phid
+set( 'SQL_PRIVHISTORY_SELECT_BY_PHID', q/
+      SELECT phid, eid, priv, effective, remark FROM privhistory
+      WHERE phid = ? 
+      / );
+
+# SQL_PRIVHISTORY_SELECT_RANGE
+#     SQL to select a range of privhistory records
+set( 'SQL_PRIVHISTORY_SELECT_RANGE', q/
+      SELECT phid, eid, priv, effective, remark FROM privhistory 
+      WHERE eid = ? AND effective <@ CAST( ? AS tsrange )
+      ORDER BY effective
+      / );
+
 # -----------------------------------
 # DO NOT EDIT ANYTHING BELOW THIS LINE
 # -----------------------------------
